/************************************************************************
 **
 **  @file   tst_vlayoutdetail.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   17 5, 2015
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2015 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/

#ifndef TST_VLAYOUTDETAIL_H
#define TST_VLAYOUTDETAIL_H

#include "../vtest/abstracttest.h"

class TST_VLayoutDetail : public AbstractTest
{
    Q_OBJECT // NOLINT
public:
    explicit TST_VLayoutDetail(QObject *parent = nullptr);

private slots:
    void RemoveDublicates() const;

private:
    void Case1() const;
    auto InputPointsCase1() const -> QVector<QPointF>;
    auto OutputPointsCase1() const -> QVector<QPointF>;

    void Case2() const;
    auto InputPointsCase2() const -> QVector<QPointF>;
    auto OutputPointsCase2() const -> QVector<QPointF>;

    void Case3() const;
    auto InputPointsCase3() const -> QVector<QPointF>;
    auto OutputPointsCase3() const -> QVector<QPointF>;
};

#endif // TST_VLAYOUTDETAIL_H
